==> nextcloud-27.1.11.tgz: nextcloud/apps/activity/l10n/ga.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fotha gníomhaíochta pearsanta do %s",
    "Your feed URL is invalid" : "Tá do URL fotha neamhbhailí",
    "Activity feed for %1$s" : "Fotha gníomhaíochta le haghaidh%1$s",
    "Activity feed" : "Fotha gníomhaíochta",
    "Your settings have been updated." : "Nuashonraíodh do shocruithe.",
    "Settings have been updated." : "Nuashonraíodh na socruithe.",
    "Recent activity" : "Gníomhaíocht le déanaí",
    "No activities" : "Gan gníomhaíochtaí",
    "More activities" : "Tuilleadh gníomhaíochtaí",
    "Daily activity summary for %s" : "Achoimre ar ghníomhaíocht laethúil le haghaidh %s",
    "_and %n more _::_and %n more _" : ["agus %n níos mó","agus %n níos mó","agus %n níos mó","agus %n níos mó"," agus %n níos mó"],
    "All activities" : "Gach gníomhaíocht",
    "By others" : "Ag daoine eile",
    "By you" : "Leat",
    "Activity at %s" : "Gníomhaíocht ag%s",
    "Hello %s" : "Dia duit %s",
    "Hello %s," : "Dia duit %s,",
    "There was some activity at %s" : "Bhí roinnt gníomhaíochta ag%s",
    "Mail" : "Post",
    "Push" : "Brúigh",
    "Activity" : "Gníomhaíocht",
    "Notifications" : "Fógraí",
    "This application enables people to view a log of activities about them, their files or other data." : "Cuireann an feidhmchlár seo ar chumas daoine féachaint ar loga gníomhaíochtaí fúthu, a gcomhaid nó sonraí eile.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ligeann an aip seo do dhaoine gníomhartha a bhaineann lena gcuid comhad agus sonraí a fheiceáil in Nextcloud.\n\t\tIs féidir le gach duine a shocruithe gníomhaíochta aonair a chumrú sna socruithe pearsanta,\n\t\ta roghnú cén ghníomhaíocht ba chóir a bhrú ar fhóin phóca, a sheoladh trí ríomhphost\n\t\tnó an seoltar achoimre laethúil gach maidin.\n\t\tTá tuilleadh eolais ar fáil i gcáipéisíocht na Gníomhaíochta.",
    "Activity notification configuration" : "Cumraíocht fógra gníomhaíochta",
    "Send email" : "Seol ríomhphost",
    "Send push notification" : "Seol fógra brúigh",
    "Today" : "Inniu",
    "Yesterday" : "Inné",
    "You need to set up your email address before you can receive notification emails." : "Ní mór duit do sheoladh ríomhphoist a shocrú sula mbeidh tú in ann ríomhphoist fógra a fháil.",
    "Send activity emails" : "Seol ríomhphoist ghníomhaíochta",
    "As soon as possible" : "Chomh luath agus is féidir",
    "Hourly" : "in aghaidh na huaire",
    "Daily" : "Laethúil",
    "Weekly" : "Seachtainiúil",
    "You commented" : "Rinne tú trácht",
    "Message deleted by author" : "Scrios an t-údar an teachtaireacht",
    "Open {filename}" : "Oscail {filename}",
    "in {path}" : "in {path}",
    "Home" : "Baile",
    "Loading activities" : "Gníomhaíochtaí á lódáil",
    "This stream will show events like additions, changes & shares" : "Léireoidh an sruth seo imeachtaí ar nós breisithe, athruithe & scaireanna",
    "No activity yet" : "Níl aon ghníomhaíocht fós",
    "Loading more activities" : "Tuilleadh gníomhaíochtaí á lódáil",
    "No more activities." : "Uimh gníomhaíochtaí níos mó.",
    "Could not load activities" : "Níorbh fhéidir gníomhaíochtaí a lódáil",
    "Activity settings" : "Socruithe gníomhaíochta",
    "Enable RSS feed" : "Cumasaigh fotha RSS",
    "RSS feed" : "Fotha RSS",
    "Copy RSS feed link" : "Cóipeáil nasc fotha RSS",
    "Personal notification settings" : "Socruithe fógraí pearsanta",
    "Could not enable RSS link" : "Níorbh fhéidir nasc RSS a chumasú",
    "RSS link copied to clipboard" : "Cóipeáladh an nasc RSS chuig an ngearrthaisce",
    "Could not copy the RSS link, please copy manually:" : "Níorbh fhéidir an nasc RSS a chóipeáil, cóip de láimh le do thoil:",
    "Unable to load the activity list" : "Ní féidir an liosta gníomhaíochta a lódáil",
    "Notification" : "Fógra",
    "Enable notification emails" : "Cumasaigh fógraí ríomhphoist",
    "Choose for which activities you want to get an email or push notification." : "Roghnaigh na gníomhaíochtaí ar mhaith leat ríomhphost nó fógra a bhrú ina leith.",
    "Choose for which activities you want to get a push notification." : "Roghnaigh na gníomhaíochtaí ar mhaith leat fógra brú a fháil ina leith.",
    "Daily activity summary" : "Achoimre ar ghníomhaíocht laethúil",
    "Send daily activity summary in the morning" : "Seol achoimre ar ghníomhaíocht laethúil ar maidin",
    "Default settings" : "Socruithe réamhshocraithe",
    "Configure the default notification settings for new accounts." : "Cumraigh na socruithe fógra réamhshocraithe do chuntais nua.",
    "Unable to save the settings" : "Ní féidir na socruithe a shábháil",
    "No more events to load" : "Níl a thuilleadh imeachtaí le luchtú",
    "Copied!" : "Cóipeáladh!",
    "Not supported!" : "Gan tacaíocht!",
    "Press ⌘-C to copy." : "Brúigh ⌘-C chun cóip a dhéanamh.",
    "Press Ctrl-C to copy." : "Brúigh Ctrl-C chun cóip a dhéanamh.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "There are no events for this filter" : "Níl aon imeachtaí don scagaire seo",
    "Could not load activites" : "Níorbh fhéidir an ghníomhaíocht a lódáil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-28.0.8.tgz: nextcloud/apps/activity/l10n/ga.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fotha gníomhaíochta pearsanta do %s",
    "Your feed URL is invalid" : "Tá do URL fotha neamhbhailí",
    "Activity feed for %1$s" : "Fotha gníomhaíochta le haghaidh %1$s",
    "Activity feed" : "Fotha gníomhaíochta",
    "Your settings have been updated." : "Nuashonraíodh do shocruithe.",
    "Settings have been updated." : "Nuashonraíodh na socruithe.",
    "Recent activity" : "Gníomhaíocht le déanaí",
    "No activities" : "Gan aon ghníomhaíochtaí",
    "More activities" : "Tuilleadh gníomhaíochtaí",
    "Daily activity summary for %s" : "Achoimre ar ghníomhaíocht laethúil le haghaidh %s",
    "_and %n more…_::_and %n more…_" : ["agus %n eile…","agus %n eile…","agus %n eile…","agus %n eile…","agus %n eile…"],
    "All activities" : "Gach gníomhaíocht",
    "By others" : "Ag daoine eile",
    "By you" : "Leat",
    "Activity at %s" : "Gníomhaíocht ag %s",
    "Hello %s" : "Dia duit %s",
    "Hello %s," : "Dia duit %s,",
    "There was some activity at %s" : "Bhí roinnt gníomhaíochta ag %s",
    "_and %n more _::_and %n more _" : ["agus %n níos mó","agus %n níos mó","agus %n níos mó","agus %n níos mó","agus %n níos mó"],
    "Mail" : "Post",
    "Push" : "Brú",
    "Activity" : "Gníomhaíocht",
    "Notifications" : "Fógraí",
    "This application enables people to view a log of activities about them, their files or other data." : "Cuireann an feidhmchlár seo ar chumas daoine féachaint ar loga gníomhaíochtaí fúthu, a gcomhaid nó sonraí eile.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ligeann an aip seo do dhaoine gníomhartha a bhaineann lena gcuid comhad agus sonraí a fheiceáil in Nextcloud.\n\t\tIs féidir le gach duine a shocruithe gníomhaíochta aonair a chumrú sna socruithe pearsanta,\n\t\ta roghnú cén ghníomhaíocht ba chóir a bhrú ar fhóin phóca, a sheoladh trí ríomhphost\n\t\tnó an seoltar achoimre laethúil gach maidin.\n\t\tTá tuilleadh eolais ar fáil i gcáipéisíocht na Gníomhaíochta.",
    "Activity notification configuration" : "Cumraíocht fógra gníomhaíochta",
    "Send email" : "Seol ríomhphost",
    "Send push notification" : "Seol fógra brú",
    "Today" : "Inniu",
    "Yesterday" : "Inné",
    "You need to set up your email address before you can receive notification emails." : "Ní mór duit do sheoladh ríomhphoist a shocrú sula mbeidh tú in ann ríomhphoist fógra a fháil.",
    "Send activity emails" : "Seol ríomhphoist ghníomhaíochta",
    "As soon as possible" : "Chomh luath agus is féidir",
    "Hourly" : "Uairiúil",
    "Daily" : "Laethúil",
    "Weekly" : "Seachtainiúil",
    "You commented" : "Rinne tú trácht",
    "Message deleted by author" : "Scrios an t-údar an teachtaireacht",
    "Open {filename}" : "Oscail {filename}",
    "in {path}" : "in {path}",
    "Home" : "Baile",
    "Loading activities" : "Gníomhaíochtaí á lódáil",
    "This stream will show events like additions, changes & shares" : "Taispeánfaidh an sruth seo imeachtaí cosúil le breisithe, athruithe agus roinnt scairteanna.",
    "No activity yet" : "Níl aon ghníomhaíocht fós",
    "Loading more activities" : "Tuilleadh gníomhaíochtaí á lódáil",
    "No more activities." : "Níl gníomhaíochtaí eile ann.",
    "Could not load activities" : "Níorbh fhéidir gníomhaíochtaí a lódáil",
    "Activity settings" : "Socruithe gníomhaíochta",
    "Enable RSS feed" : "Cumasaigh fotha RSS",
    "RSS feed" : "Fotha RSS",
    "Copy RSS feed link" : "Cóipeáil nasc fotha RSS",
    "Personal notification settings" : "Socruithe fógraí pearsanta",
    "Could not enable RSS link" : "Níorbh fhéidir an nasc RSS a chumasú",
    "RSS link copied to clipboard" : "Cóipeáladh an nasc RSS chuig an ngearrthaisce",
    "Could not copy the RSS link, please copy manually:" : "Níorbh fhéidir an nasc RSS a chóipeáil, cóip de láimh le do thoil:",
    "Unable to load the activity list" : "Ní féidir an liosta gníomhaíochta a lódáil",
    "Notification" : "Fógraí",
    "Enable notification emails" : "Cumasaigh fógraí ríomhphoist",
    "Choose for which activities you want to get an email or push notification." : "Roghnaigh na gníomhaíochtaí ar mhaith leat ríomhphost nó fógra a bhrú ina leith.",
    "Choose for which activities you want to get a push notification." : "Roghnaigh na gníomhaíochtaí ar mhaith leat fógra brú a fháil ina leith.",
    "Daily activity summary" : "Achoimre ar ghníomhaíocht laethúil",
    "Send daily activity summary in the morning" : "Seol achoimre ar ghníomhaíocht laethúil ar maidin",
    "Default settings" : "Socruithe Réamhshocraithe",
    "Configure the default notification settings for new accounts." : "Cumraigh socruithe fógra réamhshocraithe do chuntais nua.",
    "Unable to save the settings" : "Ní féidir socruithe a shábháil",
    "No more events to load" : "Níl níos mó imeachtaí le luchtú",
    "Copied!" : "Cóipeáladh!",
    "Not supported!" : "Gan tacaíocht!",
    "Press ⌘-C to copy." : "Brúigh ⌘-C chun cóip a dhéanamh.",
    "Press Ctrl-C to copy." : "Brúigh Ctrl-C chun cóip a dhéanamh.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "There are no events for this filter" : "Níl aon imeachtaí don scagaire seo",
    "Could not load activites" : "Níorbh fhéidir an ghníomhaíocht a lódáil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
